==> haskell-neat-interpolation-0.5.1.4-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-FoHLeyx64Ek6faAulgi96Y
key:                  neat-interpolation-0.5.1.4-FoHLeyx64Ek6faAulgi96Y
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  abb348886d9953a6f3a454f6f1a607c6
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.2.8/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-FoHLeyx64Ek6faAulgi96Y
depends:
    base-4.16.4.0 megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.5.1.4-103.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-1sowH8UcyWdJZxkerYcJwj
key:                  neat-interpolation-0.5.1.4-1sowH8UcyWdJZxkerYcJwj
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  ccdd04c857673045c8689546bf100c7b
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-1sowH8UcyWdJZxkerYcJwj
depends:
    base-4.17.2.1 megaparsec-9.6.1-6pqHq8BNT2333chbXCRu9H
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
